# Hotwire/Turbo helpers for Django, inspired by Rails.

[![PyPI version](https://badge.fury.io/py/django-turbo-helper.svg)](https://badge.fury.io/py/django-turbo-helper)
[![Documentation](https://img.shields.io/badge/Documentation-link-green.svg)](https://django-turbo-helper.readthedocs.io/)

## Documentation

**`django-turbo-response` has been renamed to `django-turbo-helper` since version 2.x.x**

1. For legacy `django-turbo-response` user, please check https://django-turbo-helper.readthedocs.io/en/1.0.3/
2. For `django-turbo-helper` user, please check https://django-turbo-helper.readthedocs.io/

## Stay In Touch

[Contact](https://saashammer.com/about/#contact)

## Hotwire + Django Boilerplate

Looking for a complete SaaS starter? Check out [SaaS Hammer](https://saashammer.com) — a production-ready Hotwire + Django boilerplate with authentication, billing, pre-built components and more.
